#### What is the problem?
#### What steps will reproduce the problem?
#### What version of DataLad are you using (run `datalad --version`)? On what operating system (consider running `datalad wtf`)?
#### Is there anything else that would be useful to know in this context?
#### Have you had any success using DataLad before? (to assess your expertise/prior luck.  We would welcome your testimonial additions to https://github.com/datalad/datalad/wiki/Testimonials as well)
